=== modified file 'NEWS'
--- NEWS	2008-09-26 22:08:38 +0000
+++ NEWS	2008-09-27 00:11:40 +0000
@@ -134,6 +134,10 @@
       tree walking, and modular directory listing code to aid future
       performance optimisations and refactoring. (Robert Collins)
 
+    * ``bzrlib.trace.debug_memory`` can be used to get a quick memory dump
+      in the middle of processing. It only reports memory if
+      ``/proc/PID/status`` is available. (John Arbash Meinel)
+
     * New method ``RevisionSpec.as_tree`` for representing the revision
       specifier as a revision tree object. (Lukáš Lalinský)
 

=== modified file 'bzrlib/commands.py'
--- bzrlib/commands.py	2008-08-31 19:39:01 +0000
+++ bzrlib/commands.py	2008-09-26 23:35:02 +0000
@@ -796,16 +796,7 @@
         else:
             ret = run(*run_argv)
         if 'memory' in debug.debug_flags:
-            try:
-                status_file = file('/proc/%s/status' % os.getpid(), 'rb')
-            except IOError:
-                pass
-            else:
-                status = status_file.read()
-                status_file.close()
-                trace.note("Process status after command:")
-                for line in status.splitlines():
-                    trace.note(line)
+            trace.debug_memory('Process status after command:', short=False)
         return ret or 0
     finally:
         # reset, in case we may do other commands later within the same process

=== modified file 'bzrlib/trace.py'
--- bzrlib/trace.py	2008-06-18 07:21:15 +0000
+++ bzrlib/trace.py	2008-09-26 22:14:42 +0000
@@ -388,6 +388,30 @@
     pass
 
 
+_short_fields = ('VmPeak', 'VmSize', 'VmRSS')
+
+def debug_memory(message='', short=True):
+    """Write out a memory dump."""
+    try:
+        status_file = file('/proc/%s/status' % os.getpid(), 'rb')
+    except IOError:
+        return
+    try:
+        status = status_file.read()
+    finally:
+        status_file.close()
+    if message:
+        note(message)
+    for line in status.splitlines():
+        if not short:
+            note(line)
+        else:
+            for field in _short_fields:
+                if line.startswith(field):
+                    note(line)
+                    break
+
+
 def report_exception(exc_info, err_file):
     """Report an exception to err_file (typically stderr) and to .bzr.log.
 

